@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2009 The PHP Group                                |
+   | Copyright (c) 1997-2010 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -23,7 +23,7 @@
    +----------------------------------------------------------------------+
  */
  
-/* $Id: ldap.c 287936 2009-09-01 08:42:10Z patrickallaert $ */
+/* $Id: ldap.c 293036 2010-01-03 09:23:27Z sebastian $ */
 #define IS_EXT_MODULE
 
 #ifdef HAVE_CONFIG_H
@@ -323,7 +323,7 @@ PHP_MINFO_FUNCTION(ldap)
 
 	php_info_print_table_start();
 	php_info_print_table_row(2, "LDAP Support", "enabled");
-	php_info_print_table_row(2, "RCS Version", "$Id: ldap.c 287936 2009-09-01 08:42:10Z patrickallaert $");
+	php_info_print_table_row(2, "RCS Version", "$Id: ldap.c 293036 2010-01-03 09:23:27Z sebastian $");
 
 	if (LDAPG(max_links) == -1) {
 		snprintf(tmp, 31, "%ld/unlimited", LDAPG(num_links));
@@ -1061,17 +1061,21 @@ PHP_FUNCTION(ldap_get_entries)
 	ldap = ld->link;
 	num_entries = ldap_count_entries(ldap, ldap_result);
 
-	if (num_entries == 0) return;
-	num_entries = 0;
-	
-	ldap_result_entry = ldap_first_entry(ldap, ldap_result);
-	if (ldap_result_entry == NULL) RETURN_FALSE;
-
 	array_init(return_value);
 	add_assoc_long(return_value, "count", num_entries);
 
-	while (ldap_result_entry != NULL) {
+	if (num_entries == 0) {
+		return;
+	}
+	
+	ldap_result_entry = ldap_first_entry(ldap, ldap_result);
+	if (ldap_result_entry == NULL) {
+		zval_dtor(return_value);
+		RETURN_FALSE;
+	}
 
+	num_entries = 0;
+	while (ldap_result_entry != NULL) {
 		MAKE_STD_ZVAL(tmp1);
 		array_init(tmp1);
 
@@ -2005,6 +2009,7 @@ PHP_FUNCTION(ldap_first_reference)
 		resultentry->id = Z_LVAL_PP(result);
 		zend_list_addref(resultentry->id);
 		resultentry->data = entry;
+		resultentry->ber = NULL;
 	}
 }
 /* }}} */
@@ -2033,6 +2038,7 @@ PHP_FUNCTION(ldap_next_reference)
 		resultentry_next->id = resultentry->id;
 		zend_list_addref(resultentry->id);
 		resultentry_next->data = entry_next;
+		resultentry_next->ber = NULL;
 	}
 }
 /* }}} */
